@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
 from django.contrib.sites.models import Site
@@ -27,7 +29,7 @@ class AliasInline(admin.TabularInline):
 
     def queryset(self, request):
         """Returns only non-canonical aliases."""
-        qs = self.model.aliases.get_query_set()
+        qs = self.model.aliases.get_queryset()
         ordering = self.ordering or ()
         if ordering:
             qs = qs.order_by(*ordering)
