@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import sys
 from warnings import warn
 
@@ -35,15 +37,29 @@ def SiteManager_clear_cache(self):
 class SiteCache(object):
     """Wrapper for SITE_CACHE that assigns a key_prefix."""
 
-    def __init__(self, cache=None, key_prefix=None):
-        from django.core.cache import get_cache
-
-        self._key_prefix = key_prefix
+    def __init__(self, cache=None):
+        try:
+            from django.core.cache import caches
+        except ImportError:
+            # Django < 1.7 compatibility
+            from django.core.cache import get_cache
+        else:
+            def get_cache(cache_alias):
+                return caches[cache_alias]
 
         if cache is None:
-            cache_alias = getattr(settings, 'CACHE_SITES_ALIAS', 'default')
-            cache = get_cache(cache_alias, KEY_PREFIX=self.key_prefix)
+            cache_alias = getattr(settings, 'CACHE_MULTISITE_ALIAS', 'default')
+            self._key_prefix = getattr(
+                settings,
+                'CACHE_MULTISITE_KEY_PREFIX',
+                settings.CACHES[cache_alias].get('KEY_PREFIX', '')
+            )
+            cache = get_cache(cache_alias)
             self._warn_cache_backend(cache, cache_alias)
+        else:
+            self._key_prefix = getattr(
+                settings, 'CACHE_MULTISITE_KEY_PREFIX', cache.key_prefix
+            )
         self._cache = cache
 
     def _warn_cache_backend(self, cache, cache_alias):
@@ -71,8 +87,6 @@ class SiteCache(object):
 
     @property
     def key_prefix(self):
-        if self._key_prefix is None:
-            return getattr(settings, 'CACHE_SITES_KEY_PREFIX', '')
         return self._key_prefix
 
     def get(self, key, *args, **kwargs):
