@@ -1,3 +1,5 @@
+from __future__ import print_function, unicode_literals
+
 import logging
 import os
 import tempfile
@@ -18,17 +20,8 @@ class Command(NoArgsCommand):
         )
         self.log("Updating {filename}".format(filename=filename))
 
-        with tempfile.NamedTemporaryFile(dir=os.path.dirname(filename)) as f:
-            tmpname = f.name
-
-            extract = tldextract.TLDExtract(fetch=True, cache_file=tmpname)
-            extract._get_tld_extractor()
-            self.log(
-                "Downloaded new data to {filename}".format(filename=tmpname)
-            )
-            os.rename(tmpname, filename)
-            f.delete = False    # No need to delete f any more.
-
+        extract = tldextract.TLDExtract(cache_file=filename)
+        extract.update(fetch_now=True)
         self.log("Done.")
 
     def setup_logging(self, verbosity):
@@ -41,4 +34,4 @@ class Command(NoArgsCommand):
 
     def log(self, msg, level=2):
         if self.verbosity >= level:
-            print msg
+            print(msg)
