@@ -1,12 +1,26 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+
 import os
 import tempfile
-from urlparse import urlsplit, urlunsplit
+try:
+    from urlparse import urlsplit, urlunsplit
+except ImportError:
+    from urllib.parse import urlsplit, urlunsplit
 
 from django.conf import settings
 from django.contrib.sites.models import Site, SITE_CACHE
 from django.core import mail
-from django.core.cache import get_cache
+
+try:
+    from django.core.cache import caches
+except ImportError:
+    # Django < 1.7 compatibility
+    from django.core.cache import get_cache
+else:
+    def get_cache(cache_alias):
+        return caches[cache_alias]
+
 from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import get_callable
 from django.db.models.signals import pre_save, post_delete, post_init
@@ -30,9 +44,13 @@ class DynamicSiteMiddleware(object):
 
         self.cache_alias = getattr(settings, 'CACHE_MULTISITE_ALIAS',
                                    'default')
-        self.key_prefix = getattr(settings, 'CACHE_MULTISITE_KEY_PREFIX',
-                                  '')
-        self.cache = get_cache(self.cache_alias, KEY_PREFIX=self.key_prefix)
+        self.key_prefix = getattr(
+            settings,
+            'CACHE_MULTISITE_KEY_PREFIX',
+            settings.CACHES[self.cache_alias].get('KEY_PREFIX', '')
+        )
+
+        self.cache = get_cache(self.cache_alias)
         post_init.connect(self.site_domain_cache_hook, sender=Site,
                           dispatch_uid='multisite_post_init')
         pre_save.connect(self.site_domain_changed_hook, sender=Site)
@@ -40,7 +58,7 @@ class DynamicSiteMiddleware(object):
 
     def get_cache_key(self, netloc):
         """Returns a cache key based on ``netloc``."""
-        netloc = md5_constructor(netloc)
+        netloc = md5_constructor(netloc.encode('utf-8'))
         return 'multisite.alias.%s.%s' % (self.key_prefix,
                                           netloc.hexdigest())
 
@@ -118,7 +136,7 @@ class DynamicSiteMiddleware(object):
         if callable(fallback):
             view = fallback
         else:
-            view = get_callable(fallback)
+            view = get_callable(fallback, can_fail=True)
             if not callable(view):
                 raise ImproperlyConfigured(
                     'settings.MULTISITE_FALLBACK is not callable: %s' %
@@ -205,8 +223,7 @@ class CookieDomainMiddleware(object):
     def tldextract(self, url):
         import tldextract
         if self._tldextract is None:
-            self._tldextract = tldextract.TLDExtract(fetch=True,
-                                                     cache_file=self.psl_cache)
+            self._tldextract = tldextract.TLDExtract(cache_file=self.psl_cache)
         return self._tldextract(url)
 
     def match_cookies(self, request, response):
@@ -218,7 +235,7 @@ class CookieDomainMiddleware(object):
             return response     # No cookies to edit
 
         parsed = self.tldextract(request.get_host())
-        if not parsed.tld:
+        if not parsed.suffix:
             return response     # IP address or local path
         if not parsed.domain:
             return response     # Only TLD
@@ -231,7 +248,7 @@ class CookieDomainMiddleware(object):
         else:
             subdomains = [''] + subdomains[-self.depth:]
 
-        domain = '.'.join(subdomains + [parsed.domain, parsed.tld])
+        domain = '.'.join(subdomains + [parsed.domain, parsed.suffix])
 
         for morsel in matched:
             morsel['domain'] = domain
